<?php

namespace App\Entity;

use App\Repository\NoteSharesRepository;
use Doctrine\ORM\Mapping as ORM;

#[ORM\Entity(repositoryClass: NoteSharesRepository::class)]
class NoteShares
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\ManyToOne(inversedBy: 'noteShares')]
    #[ORM\JoinColumn(nullable: false)]
    private ?User $owner = null;

    #[ORM\ManyToOne]
    #[ORM\JoinColumn(nullable: false)]
    private ?User $share = null;

    #[ORM\ManyToOne]
    #[ORM\JoinColumn(nullable: false)]
    private ?Note $note = null;

    /**
     * Retrieves the ID of the NoteShares entity.
     *
     * @return int|null The ID of the NoteShares entity, or null if not set.
     */
    public function getId(): ?int
    {
        return $this->id;
    }

    /**
     * Retrieves the owner of the object.
     *
     * @return User|null The owner of the object, or null if not set.
     */
    public function getOwner(): ?User
    {
        return $this->owner;
    }

    /**
     * A description of the entire PHP function.
     *
     * @param User|null $owner description
     * @return static
     */
    public function setOwner(?User $owner): static
    {
        $this->owner = $owner;

        return $this;
    }

    /**
     * Retrieves the share for the current instance.
     *
     * @return User|null The user who shares this instance.
     */
    public function getShare(): ?User
    {
        return $this->share;
    }

    /**
     * Set the share for the current instance.
     *
     * @param User|null $share The user to set as the share.
     * @return static The current instance.
     */
    public function setShare(?User $share): static
    {
        $this->share = $share;

        return $this;
    }

    /**
     * Retrieves the associated Note object.
     *
     * @return Note|null The associated Note object, or null if not found.
     */
    public function getNote(): ?Note
    {
        return $this->note;
    }

    /**
     * Set the note for this NoteShares entity.
     *
     * @param Note|null $note The note to set
     * @return static
     */
    public function setNote(?Note $note): static
    {
        $this->note = $note;

        return $this;
    }
}
